var hierarchy =
[
    [ "SoapDataProvider::SoapDataProvider", "class_soap_data_provider_1_1_soap_data_provider.html", null ],
    [ "SoapDataProvider::SoapDataProviderBase", "class_soap_data_provider_1_1_soap_data_provider_base.html", [
      [ "SoapDataProvider::SoapRequestDataProvider", "class_soap_data_provider_1_1_soap_request_data_provider.html", null ]
    ] ],
    [ "SoapDataProvider::SoapDataProviderFactory", "class_soap_data_provider_1_1_soap_data_provider_factory.html", null ]
];